@@ -454,20 +454,11 @@ impl Logger {
         self
     }
 
-    /// Makes the logger react cooperatively if external tools rename or delete the log file.
-    ///
-    /// By default, `flexi_logger` decides, based on your configuration, to which destination(s)
-    /// the log is written.
-    ///
-    /// If logs are written to files, `flexi_logger` expects that nobody else modifies these,
-    /// and it offers capabilities to rotate, compress, and clean up log files.
-    ///
-    /// Alternatively, tools like linux' `logrotate` can be used to rotate, compress or remove
-    /// log files. But renaming or deleting the current output file e.g. will not stop
-    /// `flexi_logger` from writing to the now renamed or even deleted file!
-    /// You should configure `flexi_logger` with `Logger::watch_external_rotations()`
-    /// to make it watch for OS events that affect its outputfile
-    /// and react with closing its current output stream and recreating its configured output file.
+    /// Tries to make the logger react cooperatively if external tools rename or delete the log file.
+    #[deprecated(
+        since = "0.22.2",
+        note = "Use LoggerHandle::reopen_outputfile() instead"
+    )]
     #[must_use]
     #[cfg(feature = "external_rotation")]
     pub fn watch_external_rotations(mut self) -> Self {
