@@ -22,10 +22,12 @@ pub(crate) enum ERRCODE {
     Flush,
     Format,
     LogFile,
+    #[cfg(feature = "external_rotation")]
+    LogFileWatcher,
     #[cfg(feature = "specfile")]
     LogSpecFile,
     Poison,
-    #[cfg(target_os = "linux")]
+    #[cfg(target_family = "unix")]
     Symlink,
     #[cfg(not(feature = "use_chrono_for_offset"))]
     Time,
@@ -38,10 +40,12 @@ impl ERRCODE {
             Self::Flush => "flush",
             Self::Format => "format",
             Self::LogFile => "logfile",
+            #[cfg(feature = "external_rotation")]
+            Self::LogFileWatcher => "logfilewatcher",
             #[cfg(feature = "specfile")]
             Self::LogSpecFile => "logspecfile",
             Self::Poison => "poison",
-            #[cfg(target_os = "linux")]
+            #[cfg(target_family = "unix")]
             Self::Symlink => "symlink",
             #[cfg(not(feature = "use_chrono_for_offset"))]
             Self::Time => "time",
